@@ -97,9 +97,47 @@ class ProjAxes(Axes):
         return super().plot(x, y, *args,
                             scalex=scalex, scaley=scaley, data=data, **kwargs)
 
-    def plot_colorline(self, x, y, data, cmap='turbo_r', vmin=None, vmax=None,
-                       linewidth=1.5, label=None, fmt=None, orientation='horizontal'):
-        """Plot a colored line."""
+    def plot_colorline(self, x, y, data, cmap=None, vmin=None, vmax=None, norm=None,
+                       label=None, fmt=None, orientation='horizontal',
+                       **kwargs):  # pylint: disable=too-many-locals
+        """Plot a colored line with a colorbar.
+
+        Parameters
+        ----------
+        x: np.ndarray
+            Projected x-coordinates.
+        y: np.ndarray
+            Projected y-coordinates.
+        data: np.ndarray
+            Value to use to color the line.
+        cmap: str, optional
+            Matplotlib colormap name (default: `turbo_r`)
+        vmin: int or float
+            Color scaling min value. If ``None`` is provided (default)
+            the data are scaled to the lowest (not-NaN) value.
+        vmax: int or float
+            Color scaling max value. If ``None`` is provided (default)
+            the data are scaled to the lowest (not-NaN) value.
+        norm: matplotlib.colors.Normalize
+            Normalisation colors normalizer. By default
+            the values will be normalized between :py:attr:`vmin`
+            and :py:attr:`vmax`.
+        label: str, optional
+            Colorbar label.
+        fmt: str, optional
+            Colorbar ticks formatter.
+        orientation: str, optional
+            Colorbar orientation (default: `horizontal`).
+        **kwargs:
+            Keyword attributes for :py:class:`LineCollection`.
+
+        Note
+        ----
+        If the range provided (with :py:attr:`vmin` and :py:attr:`vmax`)
+        is smaller than the range of the data, the colorbar will
+        be extended with arrows.
+
+        """
         points = np.transpose([x, y]).reshape(-1, 1, 2)
         segments = np.concatenate([points[:-1], points[1:]], axis=1)
 
@@ -111,11 +149,13 @@ class ProjAxes(Axes):
         if vmax is None:
             vmax = np.nanmax(data)
 
-        norm = plt.Normalize(vmin, vmax)
+        if cmap is None:
+            cmap = 'turbo_r'
+        if norm is None:
+            norm = plt.Normalize(vmin, vmax)
 
-        lc = LineCollection(segments, cmap=cmap, norm=norm)
+        lc = LineCollection(segments, cmap=cmap, norm=norm, **kwargs)
         lc.set_array(values)
-        lc.set_linewidth(linewidth)
 
         line = super(Axes, self).add_collection(lc)  # pylint: disable=bad-super-call
 
@@ -126,7 +166,7 @@ class ProjAxes(Axes):
         extend = 'both' if cmin and cmax else 'min' \
             if cmin else 'max' if cmax else 'neither'
 
-        return plt.colorbar(
+        cbar = plt.colorbar(
             line, ax=self,
             extend=extend,
             shrink=.6,
@@ -137,6 +177,8 @@ class ProjAxes(Axes):
             label=label,
         )
 
+        return cbar
+
     def add_path(self, path, *args, **kwargs):
         """Draw path."""
         self.add_patch(PathPatch(path, *args, **kwargs))
