@@ -157,12 +157,28 @@ class ROI(AbstractItem):
             if 'edgecolor' not in kwargs:
                 kwargs['edgecolor'] = self.get_ec()
 
+        if 'alpha' not in kwargs:
+            kwargs['alpha'] = self.get_alpha()
+
+        if 'linewidth' not in kwargs:
+            kwargs['linewidth'] = self.get_linewidth()
+
+        if 'linestyle' not in kwargs:
+            kwargs['linestyle'] = self.get_linestyle()
+
+        if 'zorder' not in kwargs:
+            kwargs['zorder'] = self.get_zorder()
+
         return PathPatch(self.path, **kwargs)
 
     def get_path(self):
         """ROI path."""
         return self.path
 
+    def get_alpha(self):
+        """ROI default transparency."""
+        return getattr(self, 'alpha', None)
+
     def get_fc(self):  # pylint: disable=no-self-use
         """ROI default facecolor."""
         return 'none'
@@ -171,6 +187,18 @@ class ROI(AbstractItem):
         """ROI default edgecolor."""
         return getattr(self, 'color', 'red')
 
+    def get_linewidth(self):
+        """ROI default linewidth."""
+        return getattr(self, 'linewidth', 1.5)
+
+    def get_linestyle(self):
+        """ROI default linestyle."""
+        return getattr(self, 'linestyle', 'solid')
+
+    def get_zorder(self):
+        """ROI default zorder."""
+        return getattr(self, 'zorder', 1)
+
     def contains(self, pts):
         """Check if points are inside the pixel.
 
@@ -236,18 +264,34 @@ class ROIsCollection(AbstractCollection):
         """ROI patches collection with default ROI color."""
         patches = [roi.patch() for roi in self]
 
+        if 'alpha' not in kwargs:
+            kwargs['alpha'] = self.get_alpha()
+
         if 'facecolors' not in kwargs:
             kwargs['facecolors'] = self.get_facecolors()
 
         if 'edgecolors' not in kwargs:
             kwargs['edgecolors'] = self.get_edgecolors()
 
+        if 'linewidths' not in kwargs:
+            kwargs['linewidths'] = self.get_linewidth()
+
+        if 'linestyles' not in kwargs:
+            kwargs['linestyles'] = self.get_linestyle()
+
+        if 'zorder' not in kwargs:
+            kwargs['zorder'] = self.get_zorder()
+
         return PatchCollection(patches, **kwargs)
 
     def get_paths(self):
         """Collection paths."""
         return self.collection().get_paths()
 
+    def get_alpha(self, default=None):  # pylint: disable=no-self-use
+        """Default transparencies."""
+        return default
+
     def get_facecolors(self, default='None'):  # pylint: disable=no-self-use
         """Default facecolors."""
         return default
@@ -256,6 +300,18 @@ class ROIsCollection(AbstractCollection):
         """Default edgecolors."""
         return [roi.color if hasattr(roi, 'color') else default for roi in self]
 
+    def get_linewidth(self, default=1.5):
+        """Default linewidth."""
+        return [roi.linewidth if hasattr(roi, 'linewidth') else default for roi in self]
+
+    def get_linestyle(self, default='solid'):
+        """Default linestyle."""
+        return [roi.linestyle if hasattr(roi, 'linestyle') else default for roi in self]
+
+    def get_zorder(self, default=1):  # pylint: disable=no-self-use
+        """Default zorder."""
+        return default
+
     def contains(self, pts):
         """Check if a list of points are in the ROIs collection."""
         return np.any([roi.contains(pts) for roi in self], axis=0)
