@@ -1,6 +1,6 @@
 """SPICE toolbox module."""
 
-from .pool import SPICEPool
+from .pool import SPICEPool, debug_spice_pool
 from .references import SPICERef
 from .times import et, et_range, utc
 
@@ -11,4 +11,5 @@ __all__ = [
     'utc',
     'SPICERef',
     'SPICEPool',
+    'debug_spice_pool',
 ]
