@@ -1,10 +1,11 @@
 """Trajectory module."""
 
-from .trajectory import Trajectory
+from .trajectory import Trajectory, debug_trajectory
 from .config import TrajectoryConfig
 
 
 __all__ = [
     'Trajectory',
     'TrajectoryConfig',
+    'debug_trajectory',
 ]
